From b19070f17eabab89ab513c69603501816ab3c02d Mon Sep 17 00:00:00 2001
From: Kaloyan Kovachev <kkovachev@varna.net>
Date: Sun, 8 Jun 2008 15:24:01 +0300
Subject: [PATCH] Add telnet access to CSA management

---
 src/input/vlmshell.c |   68 ++++++++++++++++++++++++++++++++++++++++++++++++++
 1 files changed, 68 insertions(+), 0 deletions(-)

diff --git a/src/input/vlmshell.c b/src/input/vlmshell.c
index 90c59d9..571561c 100644
--- a/src/input/vlmshell.c
+++ b/src/input/vlmshell.c
@@ -337,6 +337,7 @@ static int ExecuteHelp( vlm_message_t **pp_status )
     MessageAddChild( "pause" );
     MessageAddChild( "stop" );
     MessageAddChild( "seek [+-](percentage) | [+-](seconds)s | [+-](miliseconds)ms" );
+    MessageAddChild( "csa [sout] use|(ck1|first|odd)|(ck2|second|even) (1|first|odd)|(2|second|even)|(CSA Key)" );
 
     return VLC_SUCCESS;
 }
@@ -860,6 +861,72 @@ error:
     return VLC_EGENERIC;
 }
 
+static int ExecuteCSA( vlm_t *p_vlm, const int i_command, char *ppsz_command[], vlm_message_t **pp_status )
+{
+    int i_res = VLC_EGENERIC;
+
+    if( i_command == 4 && !strcmp(ppsz_command[1], "sout" ) )
+    {
+        sout_mux_t *p_mux = (sout_mux_t *)vlc_object_find_name(p_vlm, "mux_ts", FIND_ANYWHERE);
+        if ( p_mux == NULL )
+        {
+            *pp_status = vlm_MessageNew( "CSA", "No mux object found" );
+            goto error;
+        }
+
+        if( !strcmp(ppsz_command[2], "ck1" ) || !strcmp(ppsz_command[2], "odd" ) || !strcmp(ppsz_command[2], "first" ) )
+        {
+            i_res = var_SetString( p_mux, "sout-ts-csa-ck", ppsz_command[3]);
+        }
+        else if( !strcmp(ppsz_command[2], "ck2" ) || !strcmp(ppsz_command[2], "even" ) || !strcmp(ppsz_command[2], "second" ) )
+        {
+            i_res = var_SetString( p_mux, "sout-ts-csa2-ck", ppsz_command[3]);
+        }
+        else if( !strcmp(ppsz_command[2], "use" ) )
+        {
+            i_res = var_SetString( p_mux, "sout-ts-csa-use", ppsz_command[3]);
+        }
+
+        vlc_object_release( p_mux );
+    }
+    else if ( i_command == 3 )
+    {
+        demux_t *p_demux = (demux_t *)vlc_object_find_name(p_vlm, "ts", FIND_ANYWHERE);
+        if ( p_demux == NULL )
+        {
+            *pp_status = vlm_MessageNew( "CSA", "No demux object found" );
+            goto error;
+        }
+
+        if( !strcmp(ppsz_command[1], "ck1" ) || !strcmp(ppsz_command[1], "odd" ) || !strcmp(ppsz_command[1], "first" ) )
+        {
+            i_res = var_SetString( p_demux, "ts-csa-ck", ppsz_command[2]);
+        }
+        else if( !strcmp(ppsz_command[1], "ck2" ) || !strcmp(ppsz_command[1], "even" ) || !strcmp(ppsz_command[1], "second" ) )
+        {
+            i_res = var_SetString( p_demux, "ts-csa2-ck", ppsz_command[2]);
+        }
+
+        vlc_object_release( p_demux );
+    }
+
+    if ( i_res == VLC_SUCCESS )
+    {
+        *pp_status = vlm_MessageNew( ppsz_command[0], NULL );
+        return VLC_SUCCESS;
+    }
+    else if ( i_res == VLC_ENOVAR )
+    {
+        *pp_status = vlm_MessageNew( ppsz_command[0], "No CSA encryption is used." );
+        return VLC_SUCCESS;
+    }
+
+    *pp_status = vlm_MessageNew( "CSA", "Wrong command syntax" );
+
+error:
+    return VLC_EGENERIC;
+}
+
 int ExecuteCommand( vlm_t *p_vlm, const char *psz_command,
                            vlm_message_t **pp_message )
 {
@@ -928,6 +995,7 @@ int ExecuteCommand( vlm_t *p_vlm, const char *psz_command,
     else IF_EXECUTE( "load",    (i_command != 2),   ExecuteLoad(p_vlm, ppsz_command[1], &p_message) )
     else IF_EXECUTE( "new",     (i_command < 3),    ExecuteNew(p_vlm, ppsz_command[1], ppsz_command[2], i_command-3, &ppsz_command[3], &p_message) )
     else IF_EXECUTE( "setup",   (i_command < 2),    ExecuteSetup(p_vlm, ppsz_command[1], i_command-2, &ppsz_command[2], &p_message) )
+    else IF_EXECUTE( "csa",     (i_command < 3),    ExecuteCSA(p_vlm, i_command, &ppsz_command[0], &p_message) )
     else
     {
         p_message = vlm_MessageNew( ppsz_command[0], "Unknown command" );
-- 
1.5.5

